@@ -24,7 +24,6 @@
 #include <event2/buffer.h>
 #include <event2/bufferevent.h>
 #include <event2/event.h>
-#include <glog/logging.h>
 
 #include <algorithm>
 #include <atomic>
@@ -39,6 +38,7 @@
 #include "event_util.h"
 #include "fmt/format.h"
 #include "io_util.h"
+#include "logging.h"
 #include "rocksdb/write_batch.h"
 #include "rocksdb_crc32c.h"
 #include "scope_exit.h"
@@ -67,7 +67,7 @@ Status FeedSlaveThread::Start() {
     pthread_sigmask(SIG_BLOCK, &mask, &omask);
     auto s = util::SockSend(conn_->GetFD(), redis::RESP_OK, conn_->GetBufferEvent());
     if (!s.IsOK()) {
-      LOG(ERROR) << "failed to send OK response to the replica: " << s.Msg();
+      error("failed to send OK response to the replica: {}", s.Msg());
       return;
     }
     this->loop();
@@ -84,12 +84,12 @@ Status FeedSlaveThread::Start() {
 
 void FeedSlaveThread::Stop() {
   stop_ = true;
-  LOG(WARNING) << "Slave thread was terminated, would stop feeding the slave: " << conn_->GetAddr();
+  warn("Slave thread was terminated, would stop feeding the slave: {}", conn_->GetAddr());
 }
 
 void FeedSlaveThread::Join() {
   if (auto s = util::ThreadJoin(t_); !s) {
-    LOG(WARNING) << "Slave thread operation failed: " << s.Msg();
+    warn("Slave thread operation failed: {}", s.Msg());
   }
 }
 
@@ -98,7 +98,7 @@ void FeedSlaveThread::checkLivenessIfNeed() {
   const auto ping_command = redis::BulkString("ping");
   auto s = util::SockSend(conn_->GetFD(), ping_command, conn_->GetBufferEvent());
   if (!s.IsOK()) {
-    LOG(ERROR) << "Ping slave[" << conn_->GetAddr() << "] err: " << s.Msg() << ", would stop the thread";
+    error("Ping slave [{}] err: {}, would stop the thread", conn_->GetAddr(), s.Msg());
     Stop();
   }
 }
@@ -115,7 +115,7 @@ void FeedSlaveThread::loop() {
     auto curr_seq = next_repl_seq_.load();
 
     if (!iter_ || !iter_->Valid()) {
-      if (iter_) LOG(INFO) << "WAL was rotated, would reopen again";
+      if (iter_) info("WAL was rotated, would reopen again");
       if (!srv_->storage->WALHasNewData(curr_seq) || !srv_->storage->GetWALIter(curr_seq, &iter_).IsOK()) {
         iter_ = nullptr;
         usleep(yield_microseconds);
@@ -126,8 +126,9 @@ void FeedSlaveThread::loop() {
     // iter_ would be always valid here
     auto batch = iter_->GetBatch();
     if (batch.sequence != curr_seq) {
-      LOG(ERROR) << "Fatal error encountered, WAL iterator is discrete, some seq might be lost"
-                 << ", sequence " << curr_seq << " expected, but got " << batch.sequence;
+      error(
+          "Fatal error encountered, WAL iterator is discrete, some seq might be lost, sequence {} expected, but got {}",
+          curr_seq, batch.sequence);
       Stop();
       return;
     }
@@ -147,8 +148,7 @@ void FeedSlaveThread::loop() {
       // Send entire bulk which contain multiple batches
       auto s = util::SockSend(conn_->GetFD(), batches_bulk, conn_->GetBufferEvent());
       if (!s.IsOK()) {
-        LOG(ERROR) << "Write error while sending batch to slave: " << s.Msg() << ". batches: 0x"
-                   << util::StringToHex(batches_bulk);
+        error("Write error while sending batch to slave: {}. batches: 0x{}", s.Msg(), util::StringToHex(batches_bulk));
         Stop();
         return;
       }
@@ -181,7 +181,7 @@ void ReplicationThread::CallbacksStateMachine::ConnEventCB(bufferevent *bev, int
     return;
   }
   if (events & (BEV_EVENT_ERROR | BEV_EVENT_EOF)) {
-    LOG(ERROR) << "[replication] connection error/eof, reconnect the master";
+    error("[replication] connection error/eof, reconnect the master");
     // Wait a bit and reconnect
     repl_->repl_state_.store(kReplConnecting, std::memory_order_relaxed);
     std::this_thread::sleep_for(std::chrono::seconds(1));
@@ -203,7 +203,7 @@ void ReplicationThread::CallbacksStateMachine::SetWriteCB(bufferevent *bev, buff
 void ReplicationThread::CallbacksStateMachine::ReadWriteCB(bufferevent *bev) {
 LOOP_LABEL:
   assert(handler_idx_ <= handlers_.size());
-  DLOG(INFO) << "[replication] Execute handler[" << getHandlerName(handler_idx_) << "]";
+  debug("[replication] Execute handler[{}]", getHandlerName(handler_idx_));
   auto st = getHandlerFunc(handler_idx_)(repl_, bev);
   repl_->last_io_time_secs_.store(util::GetTimeStamp(), std::memory_order_relaxed);
   switch (st) {
@@ -230,11 +230,11 @@ LOOP_LABEL:
     case CBState::RESTART:  // state that can be retried some time later
       Stop();
       if (repl_->stop_flag_) {
-        LOG(INFO) << "[replication] Wouldn't restart while the replication thread was stopped";
+        info("[replication] Wouldn't restart while the replication thread was stopped");
         break;
       }
       repl_->repl_state_.store(kReplConnecting, std::memory_order_relaxed);
-      LOG(INFO) << "[replication] Retry in 10 seconds";
+      info("[replication] Retry in 10 seconds");
       std::this_thread::sleep_for(std::chrono::seconds(10));
       Start();
   }
@@ -264,7 +264,7 @@ void ReplicationThread::CallbacksStateMachine::Start() {
     last_connect_timestamp = util::GetTimeStampMS();
     auto cfd = util::SockConnect(repl_->host_, repl_->port_, repl_->srv_->GetConfig()->replication_connect_timeout_ms);
     if (!cfd) {
-      LOG(ERROR) << "[replication] Failed to connect the master, err: " << cfd.Msg();
+      error("[replication] Failed to connect the master, err: {}", cfd.Msg());
       continue;
     }
 #ifdef ENABLE_OPENSSL
@@ -272,7 +272,7 @@ void ReplicationThread::CallbacksStateMachine::Start() {
     if (repl_->srv_->GetConfig()->tls_replication) {
       ssl = SSL_new(repl_->srv_->ssl_ctx.get());
       if (!ssl) {
-        LOG(ERROR) << "Failed to construct SSL structure for new connection: " << SSLErrors{};
+        error("Failed to construct SSL structure for new connection: {}", fmt::streamed(SSLErrors{}));
         evutil_closesocket(*cfd);
         return;
       }
@@ -288,7 +288,7 @@ void ReplicationThread::CallbacksStateMachine::Start() {
       if (ssl) SSL_free(ssl);
 #endif
       close(*cfd);
-      LOG(ERROR) << "[replication] Failed to create the event socket";
+      error("[replication] Failed to create the event socket");
       continue;
     }
 #ifdef ENABLE_OPENSSL
@@ -346,9 +346,9 @@ Status ReplicationThread::Start(std::function<bool()> &&pre_fullsync_cb, std::fu
   // Clean synced checkpoint from old master because replica starts to follow new master
   auto s = rocksdb::DestroyDB(srv_->GetConfig()->sync_checkpoint_dir, rocksdb::Options());
   if (!s.ok()) {
-    LOG(WARNING) << "Can't clean synced checkpoint from master, error: " << s.ToString();
+    warn("Can't clean synced checkpoint from master, error: {}", s.ToString());
   } else {
-    LOG(WARNING) << "Clean old synced checkpoint successfully";
+    warn("Clean old synced checkpoint successfully");
   }
 
   // cleanup the old backups, so we can start replication in a clean state
@@ -368,9 +368,9 @@ void ReplicationThread::Stop() {
   stop_flag_ = true;  // Stopping procedure is asynchronous,
                       // handled by timer
   if (auto s = util::ThreadJoin(t_); !s) {
-    LOG(WARNING) << "Replication thread operation failed: " << s.Msg();
+    warn("Replication thread operation failed: {}", s.Msg());
   }
-  LOG(INFO) << "[replication] Stopped";
+  info("[replication] Stopped");
 }
 
 /*
@@ -384,7 +384,7 @@ void ReplicationThread::Stop() {
 void ReplicationThread::run() {
   base_ = event_base_new();
   if (base_ == nullptr) {
-    LOG(ERROR) << "[replication] Failed to create new ev base";
+    error("[replication] Failed to create new ev base");
     return;
   }
   psync_steps_.Start();
@@ -400,7 +400,7 @@ void ReplicationThread::run() {
 
 ReplicationThread::CBState ReplicationThread::authWriteCB(bufferevent *bev) {
   SendString(bev, redis::ArrayOfBulkStrings({"AUTH", srv_->GetConfig()->masterauth}));
-  LOG(INFO) << "[replication] Auth request was sent, waiting for response";
+  info("[replication] Auth request was sent, waiting for response");
   repl_state_.store(kReplSendAuth, std::memory_order_relaxed);
   return CBState::NEXT;
 }
@@ -413,17 +413,17 @@ ReplicationThread::CBState ReplicationThread::authReadCB(bufferevent *bev) {  //
   if (!line) return CBState::AGAIN;
   if (!ResponseLineIsOK(line.View())) {
     // Auth failed
-    LOG(ERROR) << "[replication] Auth failed: " << line.get();
+    error("[replication] Auth failed: {}", line.get());
     return CBState::RESTART;
   }
-  LOG(INFO) << "[replication] Auth response was received, continue...";
+  info("[replication] Auth response was received, continue...");
   return CBState::NEXT;
 }
 
 ReplicationThread::CBState ReplicationThread::checkDBNameWriteCB(bufferevent *bev) {
   SendString(bev, redis::ArrayOfBulkStrings({"_db_name"}));
   repl_state_.store(kReplCheckDBName, std::memory_order_relaxed);
-  LOG(INFO) << "[replication] Check db name request was sent, waiting for response";
+  info("[replication] Check db name request was sent, waiting for response");
   return CBState::NEXT;
 }
 
@@ -434,19 +434,19 @@ ReplicationThread::CBState ReplicationThread::checkDBNameReadCB(bufferevent *bev
 
   if (line[0] == '-') {
     if (isRestoringError(line.View())) {
-      LOG(WARNING) << "The master was restoring the db, retry later";
+      warn("The master was restoring the db, retry later");
     } else {
-      LOG(ERROR) << "Failed to get the db name, " << line.get();
+      error("Failed to get the db name, {}", line.get());
     }
     return CBState::RESTART;
   }
   std::string db_name = storage_->GetName();
   if (line.length == db_name.size() && !strncmp(line.get(), db_name.data(), line.length)) {
     // DB name match, we should continue to next step: TryPsync
-    LOG(INFO) << "[replication] DB name is valid, continue...";
+    info("[replication] DB name is valid, continue...");
     return CBState::NEXT;
   }
-  LOG(ERROR) << "[replication] Mismatched the db name, local: " << db_name << ", remote: " << line.get();
+  error("[replication] Mismatched the db name, local: {}, remote: {}", db_name, line.get());
   return CBState::RESTART;
 }
 
@@ -461,7 +461,7 @@ ReplicationThread::CBState ReplicationThread::replConfWriteCB(bufferevent *bev)
   }
   SendString(bev, redis::ArrayOfBulkStrings(data_to_send));
   repl_state_.store(kReplReplConf, std::memory_order_relaxed);
-  LOG(INFO) << "[replication] replconf request was sent, waiting for response";
+  info("[replication] replconf request was sent, waiting for response");
   return CBState::NEXT;
 }
 
@@ -473,21 +473,20 @@ ReplicationThread::CBState ReplicationThread::replConfReadCB(bufferevent *bev) {
   // on unknown option: first try without announce ip, if it fails again - do nothing (to prevent infinite loop)
   if (isUnknownOption(line.View()) && !next_try_without_announce_ip_address_) {
     next_try_without_announce_ip_address_ = true;
-    LOG(WARNING) << "The old version master, can't handle ip-address, "
-                 << "try without it again";
+    warn("The old version master, can't handle ip-address, try without it again");
     // Retry previous state, i.e. send replconf again
     return CBState::PREV;
   }
   if (line[0] == '-' && isRestoringError(line.View())) {
-    LOG(WARNING) << "The master was restoring the db, retry later";
+    warn("The master was restoring the db, retry later");
     return CBState::RESTART;
   }
   if (!ResponseLineIsOK(line.View())) {
-    LOG(WARNING) << "[replication] Failed to replconf: " << line.get() + 1;
+    warn("[replication] Failed to replconf: {}", line.get() + 1);
     //  backward compatible with old version that doesn't support replconf cmd
     return CBState::NEXT;
   } else {
-    LOG(INFO) << "[replication] replconf is ok, start psync";
+    info("[replication] replconf is ok, start psync");
     return CBState::NEXT;
   }
 }
@@ -517,12 +516,11 @@ ReplicationThread::CBState ReplicationThread::tryPSyncWriteCB(bufferevent *bev)
   if (!srv_->GetConfig()->use_rsid_psync || next_try_old_psync_ || replid.length() != kReplIdLength) {
     next_try_old_psync_ = false;  // Reset next_try_old_psync_
     SendString(bev, redis::ArrayOfBulkStrings({"PSYNC", std::to_string(next_seq)}));
-    LOG(INFO) << "[replication] Try to use psync, next seq: " << next_seq;
+    info("[replication] Try to use psync, next seq: {}", next_seq);
   } else {
     // NEW PSYNC "Unique Replication Sequence ID": replication id and sequence id
     SendString(bev, redis::ArrayOfBulkStrings({"PSYNC", replid, std::to_string(next_seq)}));
-    LOG(INFO) << "[replication] Try to use new psync, current unique replication sequence id: " << replid << ":"
-              << cur_seq;
+    info("[replication] Try to use new psync, current unique replication sequence id: {}:{}", replid, cur_seq);
   }
   repl_state_.store(kReplSendPSync, std::memory_order_relaxed);
   return CBState::NEXT;
@@ -534,14 +532,13 @@ ReplicationThread::CBState ReplicationThread::tryPSyncReadCB(bufferevent *bev) {
   if (!line) return CBState::AGAIN;
 
   if (line[0] == '-' && isRestoringError(line.View())) {
-    LOG(WARNING) << "The master was restoring the db, retry later";
+    warn("The master was restoring the db, retry later");
     return CBState::RESTART;
   }
 
   if (line[0] == '-' && isWrongPsyncNum(line.View())) {
     next_try_old_psync_ = true;
-    LOG(WARNING) << "The old version master, can't handle new PSYNC, "
-                 << "try old PSYNC again";
+    warn("The old version master, can't handle new PSYNC, try old PSYNC again");
     // Retry previous state, i.e. send PSYNC again
     return CBState::PREV;
   }
@@ -550,11 +547,11 @@ ReplicationThread::CBState ReplicationThread::tryPSyncReadCB(bufferevent *bev) {
     // PSYNC isn't OK, we should use FullSync
     // Switch to fullsync state machine
     fullsync_steps_.Start();
-    LOG(INFO) << "[replication] Failed to psync, error: " << line.get() << ", switch to fullsync";
+    info("[replication] Failed to psync, error: {}, switch to fullsync", line.get());
     return CBState::QUIT;
   } else {
     // PSYNC is OK, use IncrementBatchLoop
-    LOG(INFO) << "[replication] PSync is ok, start increment batch loop";
+    info("[replication] PSync is ok, start increment batch loop");
     return CBState::NEXT;
   }
 }
@@ -570,7 +567,7 @@ ReplicationThread::CBState ReplicationThread::incrementBatchLoopCB(bufferevent *
         if (!line) return CBState::AGAIN;
         incr_bulk_len_ = line.length > 0 ? std::strtoull(line.get() + 1, nullptr, 10) : 0;
         if (incr_bulk_len_ == 0) {
-          LOG(ERROR) << "[replication] Invalid increment data size";
+          error("[replication] Invalid increment data size");
           return CBState::RESTART;
         }
         incr_state_ = Incr_batch_data;
@@ -598,15 +595,15 @@ ReplicationThread::CBState ReplicationThread::incrementBatchLoopCB(bufferevent *
 
         auto s = storage_->ReplicaApplyWriteBatch(&batch);
         if (!s.IsOK()) {
-          LOG(ERROR) << "[replication] CRITICAL - Failed to write batch to local, " << s.Msg() << ". batch: 0x"
-                     << util::StringToHex(batch.Data());
+          error("[replication] CRITICAL - Failed to write batch to local, {}. batch: 0x{}", s.Msg(),
+                util::StringToHex(batch.Data()));
           return CBState::RESTART;
         }
 
         s = parseWriteBatch(batch);
         if (!s.IsOK()) {
-          LOG(ERROR) << "[replication] CRITICAL - failed to parse write batch 0x" << util::StringToHex(batch.Data())
-                     << ": " << s.Msg();
+          error("[replication] CRITICAL - failed to parse write batch 0x{}: {}", util::StringToHex(batch.Data()),
+                s.Msg());
           return CBState::RESTART;
         }
 
@@ -618,7 +615,7 @@ ReplicationThread::CBState ReplicationThread::incrementBatchLoopCB(bufferevent *
 ReplicationThread::CBState ReplicationThread::fullSyncWriteCB(bufferevent *bev) {
   SendString(bev, redis::ArrayOfBulkStrings({"_fetch_meta"}));
   repl_state_.store(kReplFetchMeta, std::memory_order_relaxed);
-  LOG(INFO) << "[replication] Start syncing data with fullsync";
+  info("[replication] Start syncing data with fullsync");
   return CBState::NEXT;
 }
 
@@ -634,31 +631,31 @@ ReplicationThread::CBState ReplicationThread::fullSyncReadCB(bufferevent *bev) {
       UniqueEvbufReadln line(input, EVBUFFER_EOL_CRLF_STRICT);
       if (!line) return CBState::AGAIN;
       if (line[0] == '-') {
-        LOG(ERROR) << "[replication] Failed to fetch meta id: " << line.get();
+        error("[replication] Failed to fetch meta id: {}", line.get());
         return CBState::RESTART;
       }
       fullsync_meta_id_ = static_cast<rocksdb::BackupID>(line.length > 0 ? std::strtoul(line.get(), nullptr, 10) : 0);
       if (fullsync_meta_id_ == 0) {
-        LOG(ERROR) << "[replication] Invalid meta id received";
+        error("[replication] Invalid meta id received");
         return CBState::RESTART;
       }
       fullsync_state_ = kFetchMetaSize;
-      LOG(INFO) << "[replication] Succeed fetching meta id: " << fullsync_meta_id_;
+      info("[replication] Succeed fetching meta id: {}", fullsync_meta_id_);
     }
     case kFetchMetaSize: {
       UniqueEvbufReadln line(input, EVBUFFER_EOL_CRLF_STRICT);
       if (!line) return CBState::AGAIN;
       if (line[0] == '-') {
-        LOG(ERROR) << "[replication] Failed to fetch meta size: " << line.get();
+        error("[replication] Failed to fetch meta size: {}", line.get());
         return CBState::RESTART;
       }
       fullsync_filesize_ = line.length > 0 ? std::strtoull(line.get(), nullptr, 10) : 0;
       if (fullsync_filesize_ == 0) {
-        LOG(ERROR) << "[replication] Invalid meta file size received";
+        error("[replication] Invalid meta file size received");
         return CBState::RESTART;
       }
       fullsync_state_ = kFetchMetaContent;
-      LOG(INFO) << "[replication] Succeed fetching meta size: " << fullsync_filesize_;
+      info("[replication] Succeed fetching meta size: {}", fullsync_filesize_);
     }
     case kFetchMetaContent: {
       std::string target_dir;
@@ -670,7 +667,7 @@ ReplicationThread::CBState ReplicationThread::fullSyncReadCB(bufferevent *bev) {
         }
         auto s = engine::Storage::ReplDataManager::ParseMetaAndSave(storage_, fullsync_meta_id_, input, &meta);
         if (!s.IsOK()) {
-          LOG(ERROR) << "[replication] Failed to parse meta and save: " << s.Msg();
+          error("[replication] Failed to parse meta and save: {}", s.Msg());
           return CBState::AGAIN;
         }
         target_dir = srv_->GetConfig()->backup_sync_dir;
@@ -679,7 +676,7 @@ ReplicationThread::CBState ReplicationThread::fullSyncReadCB(bufferevent *bev) {
         UniqueEvbufReadln line(input, EVBUFFER_EOL_CRLF_STRICT);
         if (!line) return CBState::AGAIN;
         if (line[0] == '-') {
-          LOG(ERROR) << "[replication] Failed to fetch meta info: " << line.get();
+          error("[replication] Failed to fetch meta info: {}", line.get());
           return CBState::RESTART;
         }
         std::vector<std::string> need_files = util::Split(std::string(line.get()), ",");
@@ -695,18 +692,17 @@ ReplicationThread::CBState ReplicationThread::fullSyncReadCB(bufferevent *bev) {
         if (iter != need_files.end()) need_files.erase(iter);
         auto s = engine::Storage::ReplDataManager::CleanInvalidFiles(storage_, target_dir, need_files);
         if (!s.IsOK()) {
-          LOG(WARNING) << "[replication] Failed to clean up invalid files of the old checkpoint,"
-                       << " error: " << s.Msg();
-          LOG(WARNING) << "[replication] Try to clean all checkpoint files";
+          warn("[replication] Failed to clean up invalid files of the old checkpoint, error: {}", s.Msg());
+          warn("[replication] Try to clean all checkpoint files");
           auto s = rocksdb::DestroyDB(target_dir, rocksdb::Options());
           if (!s.ok()) {
-            LOG(WARNING) << "[replication] Failed to clean all checkpoint files, error: " << s.ToString();
+            warn("[replication] Failed to clean all checkpoint files, error: {}", s.ToString());
           }
         }
       }
       assert(evbuffer_get_length(input) == 0);
       fullsync_state_ = kFetchMetaID;
-      LOG(INFO) << "[replication] Succeeded fetching full data files info, fetching files in parallel";
+      info("[replication] Succeeded fetching full data files info, fetching files in parallel");
 
       bool pre_fullsync_done = false;
       // If 'slave-empty-db-before-fullsync' is yes, we call 'pre_fullsync_cb_'
@@ -722,10 +718,10 @@ ReplicationThread::CBState ReplicationThread::fullSyncReadCB(bufferevent *bev) {
       auto s = parallelFetchFile(target_dir, meta.files);
       if (!s.IsOK()) {
         if (pre_fullsync_done) post_fullsync_cb_();
-        LOG(ERROR) << "[replication] Failed to parallel fetch files while " + s.Msg();
+        error("[replication] Failed to parallel fetch files while {}", s.Msg());
         return CBState::RESTART;
       }
-      LOG(INFO) << "[replication] Succeeded fetching files in parallel, restoring the backup";
+      info("[replication] Succeeded fetching files in parallel, restoring the backup");
 
       // Don't need to call 'pre_fullsync_cb_' again if it was called before
       if (!pre_fullsync_done && !pre_fullsync_cb_()) return CBState::RESTART;
@@ -737,18 +733,18 @@ ReplicationThread::CBState ReplicationThread::fullSyncReadCB(bufferevent *bev) {
         s = storage_->RestoreFromCheckpoint();
       }
       if (!s.IsOK()) {
-        LOG(ERROR) << "[replication] Failed to restore backup while " + s.Msg() + ", restart fullsync";
+        error("[replication] Failed to restore backup while {}, restart fullsync", s.Msg());
         post_fullsync_cb_();
         return CBState::RESTART;
       }
-      LOG(INFO) << "[replication] Succeeded restoring the backup, fullsync was finish";
+      info("[replication] Succeeded restoring the backup, fullsync was finish");
       post_fullsync_cb_();
 
       // It needs to reload namespaces from DB after the full sync is done,
       // or namespaces are not visible in the replica.
       s = srv_->GetNamespace()->LoadAndRewrite();
       if (!s.IsOK()) {
-        LOG(ERROR) << "[replication] Failed to load and rewrite namespace: " << s.Msg();
+        error("[replication] Failed to load and rewrite namespace: {}", s.Msg());
       }
 
       // Switch to psync state machine again
@@ -756,10 +752,7 @@ ReplicationThread::CBState ReplicationThread::fullSyncReadCB(bufferevent *bev) {
       return CBState::QUIT;
     }
   }
-
-  LOG(ERROR) << "Should not arrive here";
-  assert(false);
-  return CBState::QUIT;
+  unreachable();
 }
 
 Status ReplicationThread::parallelFetchFile(const std::string &dir,
@@ -810,9 +803,8 @@ Status ReplicationThread::parallelFetchFile(const std::string &dir,
               skip_cnt.fetch_add(1);
               uint32_t cur_skip_cnt = skip_cnt.load();
               uint32_t cur_fetch_cnt = fetch_cnt.load();
-              LOG(INFO) << "[skip] " << f_name << " " << f_crc << ", skip count: " << cur_skip_cnt
-                        << ", fetch count: " << cur_fetch_cnt << ", progress: " << cur_skip_cnt + cur_fetch_cnt << "/"
-                        << files.size();
+              info("[skip] {} {}, skip count: {}, fetch count: {}, progress: {} / {}", f_name, f_crc, cur_skip_cnt,
+                   cur_fetch_cnt, (cur_skip_cnt + cur_fetch_cnt), files.size());
               continue;
             }
             fetch_files.push_back(f_name);
@@ -824,10 +816,8 @@ Status ReplicationThread::parallelFetchFile(const std::string &dir,
             fetch_cnt.fetch_add(1);
             uint32_t cur_skip_cnt = skip_cnt.load();
             uint32_t cur_fetch_cnt = fetch_cnt.load();
-            LOG(INFO) << "[fetch] "
-                      << "Fetched " << fetch_file << ", crc32: " << fetch_crc << ", skip count: " << cur_skip_cnt
-                      << ", fetch count: " << cur_fetch_cnt << ", progress: " << cur_skip_cnt + cur_fetch_cnt << "/"
-                      << files_count;
+            info("[fetch] Fetched {}, crc32 {}, skip count: {}, fetch count: {}, progress: {} / {}", fetch_file,
+                 fetch_crc, cur_skip_cnt, cur_fetch_cnt, cur_skip_cnt + cur_fetch_cnt, files_count);
           };
           // For master using old version, it only supports to fetch a single file by one
           // command, so we need to fetch all files by multiple command interactions.
@@ -962,14 +952,14 @@ Status ReplicationThread::fetchFiles(int sock_fd, const std::string &dir, const
 
   UniqueEvbuf evbuf;
   for (unsigned i = 0; i < files.size(); i++) {
-    DLOG(INFO) << "[fetch] Start to fetch file " << files[i];
+    debug("[fetch] Start to fetch file {}", files[i]);
     s = fetchFile(sock_fd, evbuf.get(), dir, files[i], crcs[i], fn, ssl);
     if (!s.IsOK()) {
       s = Status(Status::NotOK, "fetch file err: " + s.Msg());
-      LOG(WARNING) << "[fetch] Fail to fetch file " << files[i] << ", err: " << s.Msg();
+      warn("[fetch] Fail to fetch file {}, err: {}", files[i], s.Msg());
       break;
     }
-    DLOG(INFO) << "[fetch] Succeed fetching file " << files[i];
+    debug("[fetch] Succeed fetching file {}", files[i]);
 
     // Just for tests
     if (srv_->GetConfig()->fullsync_recv_file_delay) {
@@ -983,7 +973,7 @@ Status ReplicationThread::fetchFiles(int sock_fd, const std::string &dir, const
 void ReplicationThread::TimerCB(int, int16_t) {
   // DLOG(INFO) << "[replication] timer";
   if (stop_flag_) {
-    LOG(INFO) << "[replication] Stop ev loop";
+    info("[replication] Stop ev loop");
     event_base_loopbreak(base_);
     psync_steps_.Stop();
     fullsync_steps_.Stop();
