@@ -20,7 +20,6 @@
 
 #include "server.h"
 
-#include <glog/logging.h>
 #include <rocksdb/convenience.h>
 #include <rocksdb/statistics.h>
 #include <sys/resource.h>
@@ -43,6 +42,7 @@
 #include "common/string_util.h"
 #include "config/config.h"
 #include "fmt/format.h"
+#include "logging.h"
 #include "redis_connection.h"
 #include "rocksdb/version.h"
 #include "storage/compaction_checker.h"
@@ -105,16 +105,17 @@ Server::Server(engine::Storage *storage, Config *config)
     if (!config->unixsocket.empty() && i == 0) {
       Status s = worker->ListenUnixSocket(config->unixsocket, config->unixsocketperm, config->backlog);
       if (!s.IsOK()) {
-        LOG(ERROR) << "[server] Failed to listen on unix socket: " << config->unixsocket << ". Error: " << s.Msg();
+        error("[server] Failed to listen on unix socket: {}. Error: {}", config->unixsocket, s.Msg());
         exit(1);
       }
-      LOG(INFO) << "[server] Listening on unix socket: " << config->unixsocket;
+      info("[server] Listening on unix socket: {}", config->unixsocket);
     }
     worker_threads_.emplace_back(std::make_unique<WorkerThread>(std::move(worker)));
   }
 
   AdjustOpenFilesLimit();
   slow_log_.SetMaxEntries(config->slowlog_max_len);
+  slow_log_.SetDumpToLogfileLevel(config->slowlog_dump_logfile_level);
   perf_log_.SetMaxEntries(config->profiling_sample_record_max_len);
 }
 
@@ -125,8 +126,8 @@ Server::~Server() {
   while (GetFetchFileThreadNum() != 0) {
     usleep(100000);
     if (++counter == 600) {
-      LOG(WARNING) << "[server] Will force destroy the server after waiting 60s, leave " << GetFetchFileThreadNum()
-                   << " fetch file threads are still running";
+      warn("[server] Will force destroy the server after waiting 60s, leave {} fetch file threads are still running",
+           GetFetchFileThreadNum());
       break;
     }
   }
@@ -199,7 +200,7 @@ Status Server::Start() {
   }
 
   if (auto s = task_runner_.Start(); !s) {
-    LOG(WARNING) << "Failed to start task runner: " << s.Msg();
+    warn("Failed to start task runner: {}", s.Msg());
   }
   // setup server cron thread
   cron_thread_ = GET_OR_RET(util::CreateThread("server-cron", [this] { this->cron(); }));
@@ -239,7 +240,7 @@ Status Server::Start() {
   }));
 
   memory_startup_use_.store(Stats::GetMemoryRSS(), std::memory_order_relaxed);
-  LOG(INFO) << "[server] Ready to accept connections";
+  info("[server] Ready to accept connections");
 
   return Status::OK();
 }
@@ -255,19 +256,18 @@ void Server::Stop() {
     worker->Stop(0 /* immediately terminate  */);
   }
 
-  rocksdb::CancelAllBackgroundWork(storage->GetDB(), true);
   task_runner_.Cancel();
 }
 
 void Server::Join() {
   if (auto s = util::ThreadJoin(cron_thread_); !s) {
-    LOG(WARNING) << "Cron thread operation failed: " << s.Msg();
+    warn("Cron thread operation failed: {}", s.Msg());
   }
   if (auto s = util::ThreadJoin(compaction_checker_thread_); !s) {
-    LOG(WARNING) << "Compaction checker thread operation failed: " << s.Msg();
+    warn("Compaction checker thread operation failed: {}", s.Msg());
   }
   if (auto s = task_runner_.Join(); !s) {
-    LOG(WARNING) << s.Msg();
+    warn("{}", s.Msg());
   }
   for (const auto &worker : worker_threads_) {
     worker->Join();
@@ -298,7 +298,7 @@ Status Server::AddMaster(const std::string &host, uint32_t port, bool force_reco
                                       [this]() {
                                         this->is_loading_ = false;
                                         if (auto s = task_runner_.Start(); !s) {
-                                          LOG(WARNING) << "Failed to start task runner: " << s.Msg();
+                                          warn("Failed to start task runner: {}", s.Msg());
                                         }
                                       });
   if (s.IsOK()) {
@@ -672,7 +672,7 @@ void Server::WakeupBlockingConns(const std::string &key, size_t n_conns) {
     auto conn_ctx = iter->second.front();
     auto s = conn_ctx.owner->EnableWriteEvent(conn_ctx.fd);
     if (!s.IsOK()) {
-      LOG(ERROR) << "[server] Failed to enable write event on blocked client " << conn_ctx.fd << ": " << s.Msg();
+      error("[server] Failed to enable write event on blocked client {}: {}", conn_ctx.fd, s.Msg());
     }
     iter->second.pop_front();
   }
@@ -691,8 +691,7 @@ void Server::OnEntryAddedToStream(const std::string &ns, const std::string &key,
     if (consumer->ns == ns && entry_id > consumer->last_consumed_id) {
       auto s = consumer->owner->EnableWriteEvent(consumer->fd);
       if (!s.IsOK()) {
-        LOG(ERROR) << "[server] Failed to enable write event on blocked stream consumer " << consumer->fd << ": "
-                   << s.Msg();
+        error("[server] Failed to enable write event on blocked stream consumer {}: {}", consumer->fd, s.Msg());
       }
       it = iter->second.erase(it);
     } else {
@@ -776,11 +775,11 @@ void Server::cron() {
       if (!config_->compaction_checker_cron.IsEnabled() && config_->compact_cron.IsEnabled() &&
           config_->compact_cron.IsTimeMatch(&now)) {
         Status s = AsyncCompactDB();
-        LOG(INFO) << "[server] Schedule to compact the db, result: " << s.Msg();
+        info("[server] Schedule to compact the db, result: {}", s.Msg());
       }
       if (config_->bgsave_cron.IsEnabled() && config_->bgsave_cron.IsTimeMatch(&now)) {
         Status s = AsyncBgSaveDB();
-        LOG(INFO) << "[server] Schedule to bgsave the db, result: " << s.Msg();
+        info("[server] Schedule to bgsave the db, result: {}", s.Msg());
       }
       if (config_->dbsize_scan_cron.IsEnabled() && config_->dbsize_scan_cron.IsTimeMatch(&now)) {
         auto tokens = namespace_.List();
@@ -797,7 +796,7 @@ void Server::cron() {
 
         for (auto &ns : namespaces) {
           Status s = AsyncScanDBSize(ns);
-          LOG(INFO) << "[server] Schedule to recalculate the db size on namespace: " << ns << ", result: " << s.Msg();
+          info("[server] Schedule to recalculate the db size on namespace: {}, result: {}", ns, s.Msg());
         }
       }
     }
@@ -824,9 +823,9 @@ void Server::cron() {
             (now_secs - create_time_secs > 24 * 60 * 60)) {
           auto s = rocksdb::DestroyDB(config_->checkpoint_dir, rocksdb::Options());
           if (!s.ok()) {
-            LOG(WARNING) << "[server] Fail to clean checkpoint, error: " << s.ToString();
+            warn("[server] Fail to clean checkpoint, error: {}", s.ToString());
           } else {
-            LOG(INFO) << "[server] Clean checkpoint successfully";
+            info("[server] Clean checkpoint successfully");
           }
         }
       }
@@ -840,9 +839,9 @@ void Server::cron() {
     if (counter != 0 && counter % 600 == 0 && storage->IsDBInRetryableIOError()) {
       auto s = storage->GetDB()->Resume();
       if (s.ok()) {
-        LOG(WARNING) << "[server] Successfully resumed DB after retryable IO error";
+        warn("[server] Successfully resumed DB after retryable IO error");
       } else {
-        LOG(ERROR) << "[server] Failed to resume DB after retryable IO error: " << s.ToString();
+        error("[server] Failed to resume DB after retryable IO error: {}", s.ToString());
       }
       storage->SetDBInRetryableIOError(false);
     }
@@ -867,14 +866,14 @@ Server::InfoEntries Server::GetRocksDBInfo() {
   uint64_t num_immutable_tables = 0, memtable_flush_pending = 0, compaction_pending = 0;
   uint64_t num_running_compaction = 0, num_live_versions = 0, num_super_version = 0, num_background_errors = 0;
 
-  db->GetAggregatedIntProperty("rocksdb.size-all-mem-tables", &memtable_sizes);
-  db->GetAggregatedIntProperty("rocksdb.cur-size-all-mem-tables", &cur_memtable_sizes);
-  db->GetAggregatedIntProperty("rocksdb.num-immutable-mem-table", &num_immutable_tables);
-  db->GetAggregatedIntProperty("rocksdb.mem-table-flush-pending", &memtable_flush_pending);
-  db->GetAggregatedIntProperty("rocksdb.current-super-version-number", &num_super_version);
-  db->GetAggregatedIntProperty("rocksdb.background-errors", &num_background_errors);
-  db->GetAggregatedIntProperty("rocksdb.compaction-pending", &compaction_pending);
-  db->GetAggregatedIntProperty("rocksdb.num-live-versions", &num_live_versions);
+  db->GetAggregatedIntProperty(rocksdb::DB::Properties::kSizeAllMemTables, &memtable_sizes);
+  db->GetAggregatedIntProperty(rocksdb::DB::Properties::kCurSizeAllMemTables, &cur_memtable_sizes);
+  db->GetAggregatedIntProperty(rocksdb::DB::Properties::kNumImmutableMemTable, &num_immutable_tables);
+  db->GetAggregatedIntProperty(rocksdb::DB::Properties::kMemTableFlushPending, &memtable_flush_pending);
+  db->GetAggregatedIntProperty(rocksdb::DB::Properties::kCurrentSuperVersionNumber, &num_super_version);
+  db->GetAggregatedIntProperty(rocksdb::DB::Properties::kBackgroundErrors, &num_background_errors);
+  db->GetAggregatedIntProperty(rocksdb::DB::Properties::kCompactionPending, &compaction_pending);
+  db->GetAggregatedIntProperty(rocksdb::DB::Properties::kNumLiveVersions, &num_live_versions);
 
   {
     // All column families share the same block cache, so it's good to count a single one.
@@ -1031,6 +1030,7 @@ Server::InfoEntries Server::GetMemoryInfo() {
   entries.emplace_back("used_memory_lua", memory_lua);
   entries.emplace_back("used_memory_lua_human", used_memory_lua_human);
   entries.emplace_back("used_memory_startup", memory_startup_use_.load(std::memory_order_relaxed));
+  entries.emplace_back("mem_allocator", memory_profiler.AllocatorName());
   return entries;
 }
 
@@ -1339,7 +1339,7 @@ std::string Server::GetRocksDBStatsJson() const {
 // guarantee other threads don't access DB and its column families, then close db.
 bool Server::PrepareRestoreDB() {
   // Stop feeding slaves thread
-  LOG(INFO) << "[server] Disconnecting slaves...";
+  info("[server] Disconnecting slaves...");
   DisconnectSlaves();
 
   // If the DB is restored, the object 'db_' will be destroyed, but
@@ -1355,7 +1355,7 @@ bool Server::PrepareRestoreDB() {
   // To guarantee work threads don't access DB, we should release 'ExclusivityGuard'
   // ASAP to avoid user can't receive responses for long time, because the following
   // 'CloseDB' may cost much time to acquire DB mutex.
-  LOG(INFO) << "[server] Waiting workers for finishing executing commands...";
+  info("[server] Waiting workers for finishing executing commands...");
   while (!works_concurrency_rw_lock_.try_lock()) {
     if (replication_thread_->IsStopped()) {
       is_loading_ = false;
@@ -1366,22 +1366,22 @@ bool Server::PrepareRestoreDB() {
   works_concurrency_rw_lock_.unlock();
 
   // Stop task runner
-  LOG(INFO) << "[server] Stopping the task runner and clear task queue...";
+  info("[server] Stopping the task runner and clear task queue...");
   task_runner_.Cancel();
   if (auto s = task_runner_.Join(); !s) {
-    LOG(WARNING) << "[server] " << s.Msg();
+    warn("[server] {}", s.Msg());
   }
 
   // Cron thread, compaction checker thread, full synchronization thread
   // may always run in the background, we need to close db, so they don't actually work.
-  LOG(INFO) << "[server] Waiting for closing DB...";
+  info("[server] Waiting for closing DB...");
   storage->CloseDB();
   return true;
 }
 
 void Server::WaitNoMigrateProcessing() {
   if (config_->cluster_enabled) {
-    LOG(INFO) << "[server] Waiting until no migration task is running...";
+    info("[server] Waiting until no migration task is running...");
     slot_migrator->SetStopMigrationFlag(true);
     while (slot_migrator->GetCurrentSlotMigrationStage() != SlotMigrationStage::kNone) {
       usleep(500);
@@ -1408,7 +1408,7 @@ Status Server::AsyncCompactDB(const std::string &begin_key, const std::string &e
 
     auto s = storage->Compact(nullptr, begin.get(), end.get());
     if (!s.ok()) {
-      LOG(ERROR) << "[task runner] Failed to do compaction: " << s.ToString();
+      error("[task runner] Failed to do compaction: {}", s.ToString());
     }
 
     std::lock_guard<std::mutex> lg(db_job_mu_);
@@ -1463,7 +1463,7 @@ Status Server::AsyncScanDBSize(const std::string &ns) {
     engine::Context ctx(storage);
     auto s = db.GetKeyNumStats(ctx, "", &stats);
     if (!s.ok()) {
-      LOG(ERROR) << "failed to retrieve key num stats: " << s.ToString();
+      error("failed to retrieve key num stats: {}", s.ToString());
     }
 
     std::lock_guard<std::mutex> lg(db_job_mu_);
@@ -1478,7 +1478,7 @@ Status Server::autoResizeBlockAndSST() {
   auto total_size = storage->GetTotalSize(kDefaultNamespace);
   uint64_t total_keys = 0, estimate_keys = 0;
   for (const auto &cf_handle : *storage->GetCFHandles()) {
-    storage->GetDB()->GetIntProperty(cf_handle, "rocksdb.estimate-num-keys", &estimate_keys);
+    storage->GetDB()->GetIntProperty(cf_handle, rocksdb::DB::Properties::kEstimateNumKeys, &estimate_keys);
     total_keys += estimate_keys;
   }
 
@@ -1517,9 +1517,10 @@ Status Server::autoResizeBlockAndSST() {
   if (target_file_size_base != config_->rocks_db.target_file_size_base) {
     auto old_target_file_size_base = config_->rocks_db.target_file_size_base;
     auto s = config_->Set(this, "rocksdb.target_file_size_base", std::to_string(target_file_size_base));
-    LOG(INFO) << "[server] Resize rocksdb.target_file_size_base from " << old_target_file_size_base << " to "
-              << target_file_size_base << ", average_kv_size: " << average_kv_size << ", total_size: " << total_size
-              << ", total_keys: " << total_keys << ", result: " << s.Msg();
+    info(
+        "[server] Resize rocksdb.target_file_size_base from {} to {}, "
+        "average_kv_size: {}, total_size: {}, total_keys: {}, result: {}",
+        old_target_file_size_base, target_file_size_base, average_kv_size, total_size, total_keys, s.Msg());
     if (!s.IsOK()) {
       return s;
     }
@@ -1528,9 +1529,11 @@ Status Server::autoResizeBlockAndSST() {
   if (target_file_size_base != config_->rocks_db.write_buffer_size) {
     auto old_write_buffer_size = config_->rocks_db.write_buffer_size;
     auto s = config_->Set(this, "rocksdb.write_buffer_size", std::to_string(target_file_size_base));
-    LOG(INFO) << "[server] Resize rocksdb.write_buffer_size from " << old_write_buffer_size << " to "
-              << target_file_size_base << ", average_kv_size: " << average_kv_size << ", total_size: " << total_size
-              << ", total_keys: " << total_keys << ", result: " << s.Msg();
+    info(
+        "[server] Resize rocksdb.write_buffer_size from {} to {}, "
+        "average_kv_size: {}, total_size: {}, "
+        "total_keys: {}, result: {}",
+        old_write_buffer_size, target_file_size_base, average_kv_size, total_size, total_keys, s.Msg());
     if (!s.IsOK()) {
       return s;
     }
@@ -1538,9 +1541,11 @@ Status Server::autoResizeBlockAndSST() {
 
   if (block_size != config_->rocks_db.block_size) {
     auto s = storage->SetOptionForAllColumnFamilies("table_factory.block_size", std::to_string(block_size));
-    LOG(INFO) << "[server] Resize rocksdb.block_size from " << config_->rocks_db.block_size << " to " << block_size
-              << ", average_kv_size: " << average_kv_size << ", total_size: " << total_size
-              << ", total_keys: " << total_keys << ", result: " << s.Msg();
+    info(
+        "[server] Resize rocksdb.block_size from {} to {}, "
+        "average_kv_size: {}, total_size: {}, "
+        "total_keys: {}, result: {}",
+        config_->rocks_db.block_size, block_size, average_kv_size, total_size, total_keys, s.Msg());
     if (!s.IsOK()) {
       return s;
     }
@@ -1549,7 +1554,7 @@ Status Server::autoResizeBlockAndSST() {
   }
 
   auto s = config_->Rewrite(namespace_.List());
-  LOG(INFO) << "[server] Rewrite config, result: " << s.Msg();
+  info("[server] Rewrite config, result: {}", s.Msg());
 
   return Status::OK();
 }
@@ -1671,8 +1676,7 @@ void Server::KillClient(int64_t *killed, const std::string &addr, uint64_t id, u
       (type & kTypeMaster || (!addr.empty() && addr == master_host_ + ":" + std::to_string(master_port_)))) {
     // Stop replication thread and start a new one to replicate
     if (auto s = AddMaster(master_host_, master_port_, true); !s.IsOK()) {
-      LOG(ERROR) << "[server] Failed to add master " << master_host_ << ":" << master_port_
-                 << " with error: " << s.Msg();
+      error("[server] Failed to add master {}:{} with error: {}", master_host_, master_port_, s.Msg());
     }
     (*killed)++;
   }
@@ -1850,18 +1854,24 @@ void Server::AdjustOpenFilesLimit() {
 
   if (best_limit < max_files) {
     if (best_limit <= static_cast<int>(min_reserved_fds)) {
-      LOG(WARNING) << "[server] Your current 'ulimit -n' of " << old_limit << " is not enough for the server to start."
-                   << "Please increase your open file limit to at least " << max_files << ". Exiting.";
+      warn(
+          "[server] Your current 'ulimit -n' of {} is not enough for the server to start. "
+          "Please increase your open file limit to at least {}. Exiting.",
+          old_limit, max_files);
       exit(1);
     }
 
-    LOG(WARNING) << "[server] You requested max clients of " << max_clients << " and RocksDB max open files of "
-                 << rocksdb_max_open_file << " requiring at least " << max_files << " max file descriptors.";
-    LOG(WARNING) << "[server] Server can't set maximum open files to " << max_files
-                 << " because of OS error: " << strerror(setrlimit_error);
+    warn(
+        "[server] You requested max clients of {} and RocksDB max open files of {} "
+        "requiring at least {} max file descriptors.",
+        max_clients, rocksdb_max_open_file, max_files);
+
+    warn(
+        "[server] Server can't set maximum open files to {} "
+        "because of OS error: {}",
+        max_files, strerror(setrlimit_error));
   } else {
-    LOG(WARNING) << "[server] Increased maximum number of open files to " << max_files << " (it's originally set to "
-                 << old_limit << ")";
+    warn("[server] Increased maximum number of open files to {} (it's originally set to {})", max_files, old_limit);
   }
 }
 
@@ -1874,12 +1884,12 @@ void Server::AdjustWorkerThreads() {
   if (new_worker_threads > worker_threads_.size()) {
     delta = new_worker_threads - worker_threads_.size();
     increaseWorkerThreads(delta);
-    LOG(INFO) << "[server] Increase worker threads from " << worker_threads_.size() << " to " << new_worker_threads;
+    info("[server] Increase worker threads from {} to {}", worker_threads_.size(), new_worker_threads);
     return;
   }
 
   delta = worker_threads_.size() - new_worker_threads;
-  LOG(INFO) << "[server] Decrease worker threads from " << worker_threads_.size() << " to " << new_worker_threads;
+  info("[server] Decrease worker threads from {} to {}", worker_threads_.size(), new_worker_threads);
   decreaseWorkerThreads(delta);
 }
 
@@ -1894,7 +1904,7 @@ void Server::increaseWorkerThreads(size_t delta) {
 
 void Server::decreaseWorkerThreads(size_t delta) {
   auto current_worker_threads = worker_threads_.size();
-  DCHECK(current_worker_threads > delta);
+  CHECK(current_worker_threads > delta);
   auto remain_worker_threads = current_worker_threads - delta;
   for (size_t i = remain_worker_threads; i < current_worker_threads; i++) {
     // Unix socket will be listening on the first worker,
