@@ -47,16 +47,16 @@ TEST_F(RedisZSetTest, Add) {
   for (size_t i = 0; i < fields_.size(); i++) {
     mscores.emplace_back(MemberScore{fields_[i].ToString(), scores_[i]});
   }
-  zset_->Add(key_, ZAddFlags::Default(), &mscores, &ret);
+  zset_->Add(*ctx_, key_, ZAddFlags::Default(), &mscores, &ret);
   EXPECT_EQ(static_cast<int>(fields_.size()), ret);
   for (size_t i = 0; i < fields_.size(); i++) {
     double got = 0.0;
-    rocksdb::Status s = zset_->Score(key_, fields_[i], &got);
+    rocksdb::Status s = zset_->Score(*ctx_, key_, fields_[i], &got);
     EXPECT_EQ(scores_[i], got);
   }
-  zset_->Add(key_, ZAddFlags::Default(), &mscores, &ret);
+  zset_->Add(*ctx_, key_, ZAddFlags::Default(), &mscores, &ret);
   EXPECT_EQ(ret, 0);
-  auto s = zset_->Del(key_);
+  auto s = zset_->Del(*ctx_, key_);
 }
 
 TEST_F(RedisZSetTest, IncrBy) {
@@ -65,15 +65,15 @@ TEST_F(RedisZSetTest, IncrBy) {
   for (size_t i = 0; i < fields_.size(); i++) {
     mscores.emplace_back(MemberScore{fields_[i].ToString(), scores_[i]});
   }
-  zset_->Add(key_, ZAddFlags::Default(), &mscores, &ret);
+  zset_->Add(*ctx_, key_, ZAddFlags::Default(), &mscores, &ret);
   EXPECT_EQ(fields_.size(), ret);
   for (size_t i = 0; i < fields_.size(); i++) {
     double increment = 12.3;
     double score = 0.0;
-    zset_->IncrBy(key_, fields_[i], increment, &score);
+    zset_->IncrBy(*ctx_, key_, fields_[i], increment, &score);
     EXPECT_EQ(scores_[i] + increment, score);
   }
-  auto s = zset_->Del(key_);
+  auto s = zset_->Del(*ctx_, key_);
 }
 
 TEST_F(RedisZSetTest, Remove) {
@@ -82,16 +82,16 @@ TEST_F(RedisZSetTest, Remove) {
   for (size_t i = 0; i < fields_.size(); i++) {
     mscores.emplace_back(MemberScore{fields_[i].ToString(), scores_[i]});
   }
-  zset_->Add(key_, ZAddFlags::Default(), &mscores, &ret);
+  zset_->Add(*ctx_, key_, ZAddFlags::Default(), &mscores, &ret);
   EXPECT_EQ(fields_.size(), ret);
-  zset_->Remove(key_, fields_, &ret);
+  zset_->Remove(*ctx_, key_, fields_, &ret);
   EXPECT_EQ(fields_.size(), ret);
   for (auto &field : fields_) {
     double score = 0.0;
-    rocksdb::Status s = zset_->Score(key_, field, &score);
+    rocksdb::Status s = zset_->Score(*ctx_, key_, field, &score);
     EXPECT_TRUE(s.IsNotFound());
   }
-  auto s = zset_->Del(key_);
+  auto s = zset_->Del(*ctx_, key_);
 }
 
 TEST_F(RedisZSetTest, AddAndRemoveRepeated) {
@@ -103,24 +103,24 @@ TEST_F(RedisZSetTest, AddAndRemoveRepeated) {
   for (size_t i = 0; i < members.size(); i++) {
     mscores.emplace_back(MemberScore{members[i], scores[i]});
   }
-  zset_->Add(key_, ZAddFlags::Default(), &mscores, &ret);
+  zset_->Add(*ctx_, key_, ZAddFlags::Default(), &mscores, &ret);
   EXPECT_EQ(mscores.size() - 1, ret);
   double score = 0.0;
-  zset_->Score(key_, members[0], &score);
+  zset_->Score(*ctx_, key_, members[0], &score);
   EXPECT_EQ(scores[1], score);
   uint64_t card = 0;
-  zset_->Card(key_, &card);
+  zset_->Card(*ctx_, key_, &card);
   EXPECT_EQ(mscores.size() - 1, card);
 
   std::vector<rocksdb::Slice> members_to_remove{"m1", "m2", "m2"};
-  zset_->Remove(key_, members_to_remove, &ret);
+  zset_->Remove(*ctx_, key_, members_to_remove, &ret);
   EXPECT_EQ(members_to_remove.size() - 1, ret);
-  zset_->Card(key_, &card);
+  zset_->Card(*ctx_, key_, &card);
   EXPECT_EQ(mscores.size() - 1 - ret, card);
-  zset_->Score(key_, members[3], &score);
+  zset_->Score(*ctx_, key_, members[3], &score);
   EXPECT_EQ(scores[3], score);
 
-  auto s = zset_->Del(key_);
+  auto s = zset_->Del(*ctx_, key_);
 }
 
 TEST_F(RedisZSetTest, Range) {
@@ -130,18 +130,18 @@ TEST_F(RedisZSetTest, Range) {
     mscores.emplace_back(MemberScore{fields_[i].ToString(), scores_[i]});
   }
   uint64_t count = mscores.size() - 1;
-  zset_->Add(key_, ZAddFlags::Default(), &mscores, &ret);
+  zset_->Add(*ctx_, key_, ZAddFlags::Default(), &mscores, &ret);
   EXPECT_EQ(fields_.size(), ret);
   RangeRankSpec rank_spec;
   rank_spec.start = 0;
   rank_spec.stop = -2;
-  zset_->RangeByRank(key_, rank_spec, &mscores, nullptr);
+  zset_->RangeByRank(*ctx_, key_, rank_spec, &mscores, nullptr);
   EXPECT_EQ(mscores.size(), count);
   for (size_t i = 0; i < mscores.size(); i++) {
     EXPECT_EQ(mscores[i].member, fields_[i].ToString());
     EXPECT_EQ(mscores[i].score, scores_[i]);
   }
-  auto s = zset_->Del(key_);
+  auto s = zset_->Del(*ctx_, key_);
 }
 
 TEST_F(RedisZSetTest, RevRange) {
@@ -151,19 +151,19 @@ TEST_F(RedisZSetTest, RevRange) {
     mscores.emplace_back(MemberScore{fields_[i].ToString(), scores_[i]});
   }
   uint64_t count = mscores.size() - 1;
-  zset_->Add(key_, ZAddFlags::Default(), &mscores, &ret);
+  zset_->Add(*ctx_, key_, ZAddFlags::Default(), &mscores, &ret);
   EXPECT_EQ(static_cast<int>(fields_.size()), ret);
   RangeRankSpec rank_spec;
   rank_spec.start = 0;
   rank_spec.stop = -2;
   rank_spec.reversed = true;
-  zset_->RangeByRank(key_, rank_spec, &mscores, nullptr);
+  zset_->RangeByRank(*ctx_, key_, rank_spec, &mscores, nullptr);
   EXPECT_EQ(mscores.size(), count);
   for (size_t i = 0; i < mscores.size(); i++) {
     EXPECT_EQ(mscores[i].member, fields_[count - i].ToString());
     EXPECT_EQ(mscores[i].score, scores_[count - i]);
   }
-  auto s = zset_->Del(key_);
+  auto s = zset_->Del(*ctx_, key_);
 }
 
 TEST_F(RedisZSetTest, PopMin) {
@@ -172,14 +172,14 @@ TEST_F(RedisZSetTest, PopMin) {
   for (size_t i = 0; i < fields_.size(); i++) {
     mscores.emplace_back(MemberScore{fields_[i].ToString(), scores_[i]});
   }
-  zset_->Add(key_, ZAddFlags::Default(), &mscores, &ret);
+  zset_->Add(*ctx_, key_, ZAddFlags::Default(), &mscores, &ret);
   EXPECT_EQ(fields_.size(), ret);
-  zset_->Pop(key_, static_cast<int>(mscores.size() - 1), true, &mscores);
+  zset_->Pop(*ctx_, key_, static_cast<int>(mscores.size() - 1), true, &mscores);
   for (size_t i = 0; i < mscores.size(); i++) {
     EXPECT_EQ(mscores[i].member, fields_[i].ToString());
     EXPECT_EQ(mscores[i].score, scores_[i]);
   }
-  zset_->Pop(key_, 1, true, &mscores);
+  zset_->Pop(*ctx_, key_, 1, true, &mscores);
   EXPECT_EQ(mscores[0].member, fields_[fields_.size() - 1].ToString());
   EXPECT_EQ(mscores[0].score, scores_[fields_.size() - 1]);
 }
@@ -191,14 +191,14 @@ TEST_F(RedisZSetTest, PopMax) {
   for (size_t i = 0; i < fields_.size(); i++) {
     mscores.emplace_back(MemberScore{fields_[i].ToString(), scores_[i]});
   }
-  zset_->Add(key_, ZAddFlags::Default(), &mscores, &ret);
+  zset_->Add(*ctx_, key_, ZAddFlags::Default(), &mscores, &ret);
   EXPECT_EQ(fields_.size(), ret);
-  zset_->Pop(key_, static_cast<int>(mscores.size() - 1), false, &mscores);
+  zset_->Pop(*ctx_, key_, static_cast<int>(mscores.size() - 1), false, &mscores);
   for (size_t i = 0; i < mscores.size(); i++) {
     EXPECT_EQ(mscores[i].member, fields_[count - i - 1].ToString());
     EXPECT_EQ(mscores[i].score, scores_[count - i - 1]);
   }
-  zset_->Pop(key_, 1, true, &mscores);
+  zset_->Pop(*ctx_, key_, 1, true, &mscores);
   EXPECT_EQ(mscores[0].member, fields_[0].ToString());
 }
 
@@ -209,13 +209,13 @@ TEST_F(RedisZSetTest, RangeByLex) {
   for (size_t i = 0; i < fields_.size(); i++) {
     mscores.emplace_back(MemberScore{fields_[i].ToString(), scores_[i]});
   }
-  zset_->Add(key_, ZAddFlags::Default(), &mscores, &ret);
+  zset_->Add(*ctx_, key_, ZAddFlags::Default(), &mscores, &ret);
   EXPECT_EQ(count, ret);
 
   RangeLexSpec spec;
   spec.min = fields_[0].ToString();
   spec.max = fields_[fields_.size() - 1].ToString();
-  zset_->RangeByLex(key_, spec, &mscores, nullptr);
+  zset_->RangeByLex(*ctx_, key_, spec, &mscores, nullptr);
   EXPECT_EQ(mscores.size(), fields_.size());
   for (size_t i = 0; i < mscores.size(); i++) {
     EXPECT_EQ(mscores[i].member, fields_[i].ToString());
@@ -223,7 +223,7 @@ TEST_F(RedisZSetTest, RangeByLex) {
   }
 
   spec.minex = true;
-  zset_->RangeByLex(key_, spec, &mscores, nullptr);
+  zset_->RangeByLex(*ctx_, key_, spec, &mscores, nullptr);
   EXPECT_EQ(mscores.size(), fields_.size() - 1);
   for (size_t i = 0; i < mscores.size(); i++) {
     EXPECT_EQ(mscores[i].member, fields_[i + 1].ToString());
@@ -232,7 +232,7 @@ TEST_F(RedisZSetTest, RangeByLex) {
 
   spec.minex = false;
   spec.maxex = true;
-  zset_->RangeByLex(key_, spec, &mscores, nullptr);
+  zset_->RangeByLex(*ctx_, key_, spec, &mscores, nullptr);
   EXPECT_EQ(mscores.size(), fields_.size() - 1);
   for (size_t i = 0; i < mscores.size(); i++) {
     EXPECT_EQ(mscores[i].member, fields_[i].ToString());
@@ -241,7 +241,7 @@ TEST_F(RedisZSetTest, RangeByLex) {
 
   spec.minex = true;
   spec.maxex = true;
-  zset_->RangeByLex(key_, spec, &mscores, nullptr);
+  zset_->RangeByLex(*ctx_, key_, spec, &mscores, nullptr);
   EXPECT_EQ(mscores.size(), fields_.size() - 2);
   for (size_t i = 0; i < mscores.size(); i++) {
     EXPECT_EQ(mscores[i].member, fields_[i + 1].ToString());
@@ -253,14 +253,14 @@ TEST_F(RedisZSetTest, RangeByLex) {
   spec.max = "+";
   spec.max_infinite = true;
   spec.reversed = true;
-  zset_->RangeByLex(key_, spec, &mscores, nullptr);
+  zset_->RangeByLex(*ctx_, key_, spec, &mscores, nullptr);
   EXPECT_EQ(mscores.size(), fields_.size());
   for (size_t i = 0; i < mscores.size(); i++) {
     EXPECT_EQ(mscores[i].member, fields_[count - i - 1].ToString());
     EXPECT_EQ(mscores[i].score, scores_[count - i - 1]);
   }
 
-  auto s = zset_->Del(key_);
+  auto s = zset_->Del(*ctx_, key_);
 }
 
 TEST_F(RedisZSetTest, RangeByScore) {
@@ -269,14 +269,14 @@ TEST_F(RedisZSetTest, RangeByScore) {
   for (size_t i = 0; i < fields_.size(); i++) {
     mscores.emplace_back(MemberScore{fields_[i].ToString(), scores_[i]});
   }
-  zset_->Add(key_, ZAddFlags::Default(), &mscores, &ret);
+  zset_->Add(*ctx_, key_, ZAddFlags::Default(), &mscores, &ret);
   EXPECT_EQ(fields_.size(), ret);
 
   // test case: inclusive the min and max score
   RangeScoreSpec spec;
   spec.min = scores_[0];
   spec.max = scores_[scores_.size() - 2];
-  zset_->RangeByScore(key_, spec, &mscores, nullptr);
+  zset_->RangeByScore(*ctx_, key_, spec, &mscores, nullptr);
   EXPECT_EQ(mscores.size(), scores_.size() - 1);
   for (size_t i = 0; i < mscores.size(); i++) {
     EXPECT_EQ(mscores[i].member, fields_[i].ToString());
@@ -284,7 +284,7 @@ TEST_F(RedisZSetTest, RangeByScore) {
   }
   // test case: exclusive the min score
   spec.minex = true;
-  zset_->RangeByScore(key_, spec, &mscores, nullptr);
+  zset_->RangeByScore(*ctx_, key_, spec, &mscores, nullptr);
   EXPECT_EQ(mscores.size(), scores_.size() - 3);
   for (size_t i = 0; i < mscores.size(); i++) {
     EXPECT_EQ(mscores[i].member, fields_[i + 2].ToString());
@@ -293,7 +293,7 @@ TEST_F(RedisZSetTest, RangeByScore) {
   // test case: exclusive the max score
   spec.minex = false;
   spec.maxex = true;
-  zset_->RangeByScore(key_, spec, &mscores, nullptr);
+  zset_->RangeByScore(*ctx_, key_, spec, &mscores, nullptr);
   EXPECT_EQ(mscores.size(), scores_.size() - 3);
   for (size_t i = 0; i < mscores.size(); i++) {
     EXPECT_EQ(mscores[i].member, fields_[i].ToString());
@@ -302,13 +302,13 @@ TEST_F(RedisZSetTest, RangeByScore) {
   // test case: exclusive the min and max score
   spec.minex = true;
   spec.maxex = true;
-  zset_->RangeByScore(key_, spec, &mscores, nullptr);
+  zset_->RangeByScore(*ctx_, key_, spec, &mscores, nullptr);
   EXPECT_EQ(mscores.size(), scores_.size() - 5);
   for (size_t i = 0; i < mscores.size(); i++) {
     EXPECT_EQ(mscores[i].member, fields_[i + 2].ToString());
     EXPECT_EQ(mscores[i].score, scores_[i + 2]);
   }
-  auto s = zset_->Del(key_);
+  auto s = zset_->Del(*ctx_, key_);
 }
 
 TEST_F(RedisZSetTest, RangeByScoreWithLimit) {
@@ -317,19 +317,19 @@ TEST_F(RedisZSetTest, RangeByScoreWithLimit) {
   for (size_t i = 0; i < fields_.size(); i++) {
     mscores.emplace_back(MemberScore{fields_[i].ToString(), scores_[i]});
   }
-  zset_->Add(key_, ZAddFlags::Default(), &mscores, &ret);
+  zset_->Add(*ctx_, key_, ZAddFlags::Default(), &mscores, &ret);
   EXPECT_EQ(fields_.size(), ret);
 
   RangeScoreSpec spec;
   spec.offset = 1;
   spec.count = 2;
-  zset_->RangeByScore(key_, spec, &mscores, nullptr);
+  zset_->RangeByScore(*ctx_, key_, spec, &mscores, nullptr);
   EXPECT_EQ(mscores.size(), 2);
   for (size_t i = 0; i < mscores.size(); i++) {
     EXPECT_EQ(mscores[i].member, fields_[i + 1].ToString());
     EXPECT_EQ(mscores[i].score, scores_[i + 1]);
   }
-  auto s = zset_->Del(key_);
+  auto s = zset_->Del(*ctx_, key_);
 }
 
 TEST_F(RedisZSetTest, RemRangeByScore) {
@@ -338,19 +338,19 @@ TEST_F(RedisZSetTest, RemRangeByScore) {
   for (size_t i = 0; i < fields_.size(); i++) {
     mscores.emplace_back(MemberScore{fields_[i].ToString(), scores_[i]});
   }
-  zset_->Add(key_, ZAddFlags::Default(), &mscores, &ret);
+  zset_->Add(*ctx_, key_, ZAddFlags::Default(), &mscores, &ret);
   EXPECT_EQ(fields_.size(), ret);
   RangeScoreSpec spec;
   spec.with_deletion = true;
 
   spec.min = scores_[0];
   spec.max = scores_[scores_.size() - 2];
-  zset_->RangeByScore(key_, spec, nullptr, &ret);
+  zset_->RangeByScore(*ctx_, key_, spec, nullptr, &ret);
   EXPECT_EQ(scores_.size() - 1, ret);
 
   spec.min = scores_[scores_.size() - 1];
   spec.max = spec.min;
-  zset_->RangeByScore(key_, spec, nullptr, &ret);
+  zset_->RangeByScore(*ctx_, key_, spec, nullptr, &ret);
   EXPECT_EQ(1, ret);
 }
 
@@ -360,7 +360,7 @@ TEST_F(RedisZSetTest, RemoveRangeByRank) {
   for (size_t i = 0; i < fields_.size(); i++) {
     mscores.emplace_back(MemberScore{fields_[i].ToString(), scores_[i]});
   }
-  zset_->Add(key_, ZAddFlags::Default(), &mscores, &ret);
+  zset_->Add(*ctx_, key_, ZAddFlags::Default(), &mscores, &ret);
   EXPECT_EQ(fields_.size(), ret);
 
   RangeRankSpec spec;
@@ -368,12 +368,12 @@ TEST_F(RedisZSetTest, RemoveRangeByRank) {
 
   spec.start = 0;
   spec.stop = static_cast<int>(fields_.size() - 2);
-  zset_->RangeByRank(key_, spec, nullptr, &ret);
+  zset_->RangeByRank(*ctx_, key_, spec, nullptr, &ret);
   EXPECT_EQ(fields_.size() - 1, ret);
 
   spec.start = 0;
   spec.stop = 2;
-  zset_->RangeByRank(key_, spec, nullptr, &ret);
+  zset_->RangeByRank(*ctx_, key_, spec, nullptr, &ret);
   EXPECT_EQ(1, ret);
 }
 
@@ -383,7 +383,7 @@ TEST_F(RedisZSetTest, RemoveRevRangeByRank) {
   for (size_t i = 0; i < fields_.size(); i++) {
     mscores.emplace_back(MemberScore{fields_[i].ToString(), scores_[i]});
   }
-  zset_->Add(key_, ZAddFlags::Default(), &mscores, &ret);
+  zset_->Add(*ctx_, key_, ZAddFlags::Default(), &mscores, &ret);
   EXPECT_EQ(fields_.size(), ret);
 
   RangeRankSpec spec;
@@ -391,12 +391,12 @@ TEST_F(RedisZSetTest, RemoveRevRangeByRank) {
 
   spec.start = 0;
   spec.stop = static_cast<int>(fields_.size() - 2);
-  zset_->RangeByRank(key_, spec, nullptr, &ret);
+  zset_->RangeByRank(*ctx_, key_, spec, nullptr, &ret);
   EXPECT_EQ(fields_.size() - 1, ret);
 
   spec.start = 0;
   spec.stop = 2;
-  zset_->RangeByRank(key_, spec, nullptr, &ret);
+  zset_->RangeByRank(*ctx_, key_, spec, nullptr, &ret);
   EXPECT_EQ(1, ret);
 }
 
@@ -406,20 +406,20 @@ TEST_F(RedisZSetTest, Rank) {
   for (size_t i = 0; i < fields_.size(); i++) {
     mscores.emplace_back(MemberScore{fields_[i].ToString(), scores_[i]});
   }
-  zset_->Add(key_, ZAddFlags::Default(), &mscores, &ret);
+  zset_->Add(*ctx_, key_, ZAddFlags::Default(), &mscores, &ret);
   EXPECT_EQ(static_cast<int>(fields_.size()), ret);
 
   for (size_t i = 0; i < fields_.size(); i++) {
     int rank = 0;
     double score = 0.0;
-    zset_->Rank(key_, fields_[i], false, &rank, &score);
+    zset_->Rank(*ctx_, key_, fields_[i], false, &rank, &score);
     EXPECT_EQ(i, rank);
     EXPECT_EQ(scores_[i], score);
   }
   for (size_t i = 0; i < fields_.size(); i++) {
     int rank = 0;
     double score = 0.0;
-    zset_->Rank(key_, fields_[i], true, &rank, &score);
+    zset_->Rank(*ctx_, key_, fields_[i], true, &rank, &score);
     EXPECT_EQ(i, static_cast<int>(fields_.size() - rank - 1));
     EXPECT_EQ(scores_[i], score);
   }
@@ -427,11 +427,11 @@ TEST_F(RedisZSetTest, Rank) {
   for (const auto &member : no_exist_members) {
     int rank = 0;
     double score = 0.0;
-    zset_->Rank(key_, member, true, &rank, &score);
+    zset_->Rank(*ctx_, key_, member, true, &rank, &score);
     EXPECT_EQ(-1, rank);
     EXPECT_EQ(0.0, score);
   }
-  auto s = zset_->Del(key_);
+  auto s = zset_->Del(*ctx_, key_);
 }
 
 TEST_F(RedisZSetTest, RandMember) {
@@ -442,7 +442,7 @@ TEST_F(RedisZSetTest, RandMember) {
     for (size_t i = 0; i < fields_.size(); i++) {
       in_mscores.emplace_back(MemberScore{fields_[i].ToString(), scores_[i]});
     }
-    zset_->Add(key_, ZAddFlags::Default(), &in_mscores, &ret);
+    zset_->Add(*ctx_, key_, ZAddFlags::Default(), &in_mscores, &ret);
     EXPECT_EQ(static_cast<int>(fields_.size()), ret);
   }
 
@@ -454,7 +454,7 @@ TEST_F(RedisZSetTest, RandMember) {
   // count = 0
   {
     std::vector<MemberScore> mscores;
-    rocksdb::Status s = zset_->RandMember(key_, 0, &mscores);
+    rocksdb::Status s = zset_->RandMember(*ctx_, key_, 0, &mscores);
     EXPECT_EQ(0, mscores.size());
     EXPECT_TRUE(s.ok());
   }
@@ -462,7 +462,7 @@ TEST_F(RedisZSetTest, RandMember) {
   // count = 1/-1
   for (int64_t count : {1, -1}) {
     std::vector<MemberScore> mscores;
-    rocksdb::Status s = zset_->RandMember(key_, count, &mscores);
+    rocksdb::Status s = zset_->RandMember(*ctx_, key_, count, &mscores);
     EXPECT_EQ(1, mscores.size());
     EXPECT_TRUE(s.ok());
     EXPECT_NE(member_map.find(mscores[0].member), member_map.end());
@@ -495,7 +495,7 @@ TEST_F(RedisZSetTest, RandMember) {
            static_cast<int64_t>(fields_.size() / 2),
        }) {
     std::vector<MemberScore> mscores;
-    rocksdb::Status s = zset_->RandMember(key_, count, &mscores);
+    rocksdb::Status s = zset_->RandMember(*ctx_, key_, count, &mscores);
     EXPECT_EQ(static_cast<size_t>(count), mscores.size());
     EXPECT_TRUE(s.ok());
     ASSERT_TRUE(no_non_exist_members(mscores));
@@ -508,7 +508,7 @@ TEST_F(RedisZSetTest, RandMember) {
            -static_cast<int64_t>(fields_.size() / 2),
        }) {
     std::vector<MemberScore> mscores;
-    rocksdb::Status s = zset_->RandMember(key_, count, &mscores);
+    rocksdb::Status s = zset_->RandMember(*ctx_, key_, count, &mscores);
     EXPECT_EQ(static_cast<size_t>(-count), mscores.size());
     EXPECT_TRUE(s.ok());
     ASSERT_TRUE(no_non_exist_members(mscores));
@@ -521,7 +521,7 @@ TEST_F(RedisZSetTest, RandMember) {
            -static_cast<int64_t>(fields_.size() + 10),
        }) {
     std::vector<MemberScore> mscores;
-    rocksdb::Status s = zset_->RandMember(key_, count, &mscores);
+    rocksdb::Status s = zset_->RandMember(*ctx_, key_, count, &mscores);
     EXPECT_TRUE(s.ok());
     ASSERT_TRUE(no_non_exist_members(mscores));
     if (count > 0) {
@@ -532,7 +532,7 @@ TEST_F(RedisZSetTest, RandMember) {
     }
   }
 
-  auto s = zset_->Del(key_);
+  auto s = zset_->Del(*ctx_, key_);
   EXPECT_TRUE(s.ok());
 }
 
@@ -548,15 +548,15 @@ TEST_F(RedisZSetTest, Diff) {
   std::string k3 = "key3";
   std::vector<MemberScore> k3_mscores = {{"a", -1000.1}, {"c", -100.1}, {"e", 8000.9}};
 
-  auto s = zset_->Add(k1, ZAddFlags::Default(), &k1_mscores, &ret);
+  auto s = zset_->Add(*ctx_, k1, ZAddFlags::Default(), &k1_mscores, &ret);
   EXPECT_EQ(ret, 4);
-  zset_->Add(k2, ZAddFlags::Default(), &k2_mscores, &ret);
+  zset_->Add(*ctx_, k2, ZAddFlags::Default(), &k2_mscores, &ret);
   EXPECT_EQ(ret, 1);
-  zset_->Add(k3, ZAddFlags::Default(), &k3_mscores, &ret);
+  zset_->Add(*ctx_, k3, ZAddFlags::Default(), &k3_mscores, &ret);
   EXPECT_EQ(ret, 3);
 
   std::vector<MemberScore> mscores;
-  zset_->Diff({k1, k2, k3}, &mscores);
+  zset_->Diff(*ctx_, {k1, k2, k3}, &mscores);
 
   EXPECT_EQ(2, mscores.size());
   std::vector<MemberScore> expected_mscores = {{"b", -100.1}, {"d", 1.234}};
@@ -567,11 +567,11 @@ TEST_F(RedisZSetTest, Diff) {
     index++;
   }
 
-  s = zset_->Del(k1);
+  s = zset_->Del(*ctx_, k1);
   EXPECT_TRUE(s.ok());
-  s = zset_->Del(k2);
+  s = zset_->Del(*ctx_, k2);
   EXPECT_TRUE(s.ok());
-  s = zset_->Del(k3);
+  s = zset_->Del(*ctx_, k3);
   EXPECT_TRUE(s.ok());
 }
 
@@ -584,18 +584,18 @@ TEST_F(RedisZSetTest, DiffStore) {
   std::string k2 = "key2";
   std::vector<MemberScore> k2_mscores = {{"c", -150.1}};
 
-  auto s = zset_->Add(k1, ZAddFlags::Default(), &k1_mscores, &ret);
+  auto s = zset_->Add(*ctx_, k1, ZAddFlags::Default(), &k1_mscores, &ret);
   EXPECT_EQ(ret, 4);
-  zset_->Add(k2, ZAddFlags::Default(), &k2_mscores, &ret);
+  zset_->Add(*ctx_, k2, ZAddFlags::Default(), &k2_mscores, &ret);
   EXPECT_EQ(ret, 1);
 
   uint64_t stored_count = 0;
-  zset_->DiffStore("zsetdiff", {k1, k2}, &stored_count);
+  zset_->DiffStore(*ctx_, "zsetdiff", {k1, k2}, &stored_count);
   EXPECT_EQ(stored_count, 3);
 
   RangeScoreSpec spec;
   std::vector<MemberScore> mscores;
-  zset_->RangeByScore("zsetdiff", spec, &mscores, nullptr);
+  zset_->RangeByScore(*ctx_, "zsetdiff", spec, &mscores, nullptr);
   EXPECT_EQ(mscores.size(), 3);
 
   std::vector<MemberScore> expected_mscores = {{"a", -100.1}, {"b", -100.1}, {"d", 1.234}};
@@ -606,10 +606,10 @@ TEST_F(RedisZSetTest, DiffStore) {
     index++;
   }
 
-  s = zset_->Del(k1);
+  s = zset_->Del(*ctx_, k1);
   EXPECT_TRUE(s.ok());
-  s = zset_->Del(k2);
+  s = zset_->Del(*ctx_, k2);
   EXPECT_TRUE(s.ok());
-  s = zset_->Del("zsetdiff");
+  s = zset_->Del(*ctx_, "zsetdiff");
   EXPECT_TRUE(s.ok());
 }
