@@ -631,7 +631,7 @@ var testHash = func(t *testing.T, configs util.KvrocksServerConfigs) {
 	t.Run("HINCRBY fails against hash value with spaces (left)", func(t *testing.T) {
 		rdb.HSet(ctx, "samllhash", "str", " 11")
 		rdb.HSet(ctx, "bighash", "str", " 11")
-		pattern := "ERR.*not an integer.*"
+		pattern := "ERR.*not.*an integer.*"
 		util.ErrorRegexp(t, rdb.HIncrBy(ctx, "samllhash", "str", 1).Err(), pattern)
 		util.ErrorRegexp(t, rdb.HIncrBy(ctx, "bighash", "str", 1).Err(), pattern)
 	})
